@@ -1,7 +1,7 @@
 package Bencher::Scenario::StringFunctions::CommonPrefix;
 
-our $DATE = '2021-06-16'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-06-23'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -38,7 +38,7 @@ Bencher::Scenario::StringFunctions::CommonPrefix - Benchmark calculating common
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::StringFunctions::CommonPrefix (from Perl distribution Bencher-Scenarios-StringFunctions), released on 2021-06-16.
+This document describes version 0.003 of Bencher::Scenario::StringFunctions::CommonPrefix (from Perl distribution Bencher-Scenarios-StringFunctions), released on 2021-06-23.
 
 =head1 SYNOPSIS
 
@@ -109,23 +109,23 @@ Benchmark with default options (C<< bencher -m StringFunctions::CommonPrefix >>)
  +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                         | dataset | ds_tags | p_tags | perl | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::CommonPrefix::common_prefix | elems0  |         |        | perl |   7000000 |       100 |                 0.00% |                 0.00% | 3.9e-09 |      21 |
+ | String::CommonPrefix::common_prefix | elems0  |         |        | perl |   7000000 |       100 |                 0.00% |                 0.00% | 1.9e-09 |      27 |
  +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table2#
  {dataset=>"elems1"}
- +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+--------+---------+
- | participant                         | dataset | ds_tags | p_tags | perl | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest | errors | samples |
- +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+--------+---------+
- | String::CommonPrefix::common_prefix | elems1  |         |        | perl |   2090000 |       478 |                 0.00% |                 0.00% |  2e-10 |      24 |
- +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+--------+---------+
+ +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ | participant                         | dataset | ds_tags | p_tags | perl | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ | String::CommonPrefix::common_prefix | elems1  |         |        | perl |   2090000 |       479 |                 0.00% |                 0.00% | 2.1e-10 |      20 |
+ +-------------------------------------+---------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table3#
  {dataset=>"elems1000prefix0"}
  +-------------------------------------+------------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                         | dataset          | ds_tags | p_tags | perl | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------------+------------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::CommonPrefix::common_prefix | elems1000prefix0 |         |        | perl |      3900 |       260 |                 0.00% |                 0.00% | 4.8e-07 |      20 |
+ | String::CommonPrefix::common_prefix | elems1000prefix0 |         |        | perl |      4400 |       230 |                 0.00% |                 0.00% | 2.7e-07 |      20 |
  +-------------------------------------+------------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table4#
@@ -133,7 +133,7 @@ Benchmark with default options (C<< bencher -m StringFunctions::CommonPrefix >>)
  +-------------------------------------+------------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                         | dataset          | ds_tags | p_tags | perl | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------------+------------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::CommonPrefix::common_prefix | elems1000prefix1 |         |        | perl |      3800 |       260 |                 0.00% |                 0.00% | 2.7e-07 |      20 |
+ | String::CommonPrefix::common_prefix | elems1000prefix1 |         |        | perl |      3810 |       263 |                 0.00% |                 0.00% | 2.6e-07 |      21 |
  +-------------------------------------+------------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table5#
@@ -141,7 +141,7 @@ Benchmark with default options (C<< bencher -m StringFunctions::CommonPrefix >>)
  +-------------------------------------+-----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                         | dataset         | ds_tags | p_tags | perl | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------------+-----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::CommonPrefix::common_prefix | elems100prefix0 |         |        | perl |     42700 |      23.4 |                 0.00% |                 0.00% | 6.7e-09 |      20 |
+ | String::CommonPrefix::common_prefix | elems100prefix0 |         |        | perl |     43401 |    23.041 |                 0.00% |                 0.00% | 3.3e-11 |      20 |
  +-------------------------------------+-----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table6#
@@ -149,7 +149,7 @@ Benchmark with default options (C<< bencher -m StringFunctions::CommonPrefix >>)
  +-------------------------------------+-----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+--------+---------+
  | participant                         | dataset         | ds_tags | p_tags | perl | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest | errors | samples |
  +-------------------------------------+-----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+--------+---------+
- | String::CommonPrefix::common_prefix | elems100prefix1 |         |        | perl |     36000 |        27 |                 0.00% |                 0.00% |  4e-08 |      20 |
+ | String::CommonPrefix::common_prefix | elems100prefix1 |         |        | perl |     37300 |      26.8 |                 0.00% |                 0.00% |  1e-08 |      34 |
  +-------------------------------------+-----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+--------+---------+
 
  #table7#
@@ -157,7 +157,7 @@ Benchmark with default options (C<< bencher -m StringFunctions::CommonPrefix >>)
  +-------------------------------------+----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                         | dataset        | ds_tags | p_tags | perl | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------------+----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::CommonPrefix::common_prefix | elems10prefix0 |         |        | perl |    368000 |      2.72 |                 0.00% |                 0.00% | 2.7e-09 |      20 |
+ | String::CommonPrefix::common_prefix | elems10prefix0 |         |        | perl |    370000 |     2.703 |                 0.00% |                 0.00% | 4.4e-11 |      20 |
  +-------------------------------------+----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table8#
@@ -165,7 +165,7 @@ Benchmark with default options (C<< bencher -m StringFunctions::CommonPrefix >>)
  +-------------------------------------+----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                         | dataset        | ds_tags | p_tags | perl | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------------+----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::CommonPrefix::common_prefix | elems10prefix1 |         |        | perl |    316000 |      3.17 |                 0.00% |                 0.00% | 9.6e-10 |      34 |
+ | String::CommonPrefix::common_prefix | elems10prefix1 |         |        | perl |    300000 |         3 |                 0.00% |                 0.00% | 4.2e-08 |      20 |
  +-------------------------------------+----------------+---------+--------+------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
@@ -175,8 +175,8 @@ Benchmark module startup overhead (C<< bencher -m StringFunctions::CommonPrefix
  +----------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
  | participant          | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +----------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
- | String::CommonPrefix |        10 |                 3 |                 0.00% |                47.24% | 0.00025 |      20 |
- | perl -e1 (baseline)  |         7 |                 0 |                47.24% |                 0.00% | 0.0001  |      20 |
+ | String::CommonPrefix |       8.7 |               2.6 |                 0.00% |                42.51% | 8.7e-06 |      20 |
+ | perl -e1 (baseline)  |       6.1 |               0   |                42.51% |                 0.00% | 2.5e-05 |      20 |
  +----------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
 
 
