@@ -1,9 +1,9 @@
 package Bencher::Scenario::StringFunctions::Trim;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-16'; # DATE
+our $DATE = '2021-06-23'; # DATE
 our $DIST = 'Bencher-Scenarios-StringFunctions'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -16,6 +16,7 @@ our $scenario = {
         {fcall_template=>'String::Trim::NonRegex::trim(<str>)'},
         {fcall_template=>'String::Trim::Regex::trim(<str>)'},
         {fcall_template=>'String::Util::trim(<str>)'},
+        {fcall_template=>'Text::Minify::XS::minify(<str>)'},
     ],
     datasets => [
         {name=>'empty'        , args=>{str=>''}},
@@ -45,7 +46,7 @@ Bencher::Scenario::StringFunctions::Trim - Benchmark string trimming (removing w
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::StringFunctions::Trim (from Perl distribution Bencher-Scenarios-StringFunctions), released on 2021-06-16.
+This document describes version 0.003 of Bencher::Scenario::StringFunctions::Trim (from Perl distribution Bencher-Scenarios-StringFunctions), released on 2021-06-23.
 
 =head1 SYNOPSIS
 
@@ -75,6 +76,8 @@ L<String::Trim::Regex> 20210604
 
 L<String::Util> 1.32
 
+L<Text::Minify::XS> v0.4.2
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -111,6 +114,14 @@ Function call template:
 
 
 
+=item * Text::Minify::XS::minify (perl_code)
+
+Function call template:
+
+ Text::Minify::XS::minify(<str>)
+
+
+
 =back
 
 =head1 BENCHMARK DATASETS
@@ -146,12 +157,13 @@ Benchmark with default options (C<< bencher -m StringFunctions::Trim >>):
  #table1#
  {dataset=>"empty"}
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ | participant                  | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Util::trim           |    520000 |      1.9  |                 0.00% |               276.49% | 3.3e-09 |      20 |
- | String::Trim::NonRegex::trim |    700000 |      1    |                34.65% |               179.60% |   8e-08 |      34 |
- | String::Trim::More::trim     |   1600000 |      0.61 |               216.36% |                19.01% | 1.9e-09 |      20 |
- | String::Trim::Regex::trim    |   1900000 |      0.52 |               276.49% |                 0.00% | 3.5e-09 |      21 |
+ | String::Util::trim           |   1494000 |     669.3 |                 0.00% |               447.30% |   1e-11 |      21 |
+ | String::Trim::NonRegex::trim |   1570000 |     636   |                 5.20% |               420.25% | 1.8e-10 |      28 |
+ | String::Trim::More::trim     |   6090000 |     164   |               307.47% |                34.32% |   1e-10 |      20 |
+ | String::Trim::Regex::trim    |   7180000 |     139   |               380.77% |                13.84% | 6.9e-11 |      20 |
+ | Text::Minify::XS::minify     |   8177000 |     122.3 |               447.30% |                 0.00% |   1e-11 |      20 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table2#
@@ -159,10 +171,11 @@ Benchmark with default options (C<< bencher -m StringFunctions::Trim >>):
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Trim::Regex::trim    |      5900 |     170   |                 0.00% |              6768.62% | 2.7e-07 |      20 |
- | String::Util::trim           |     23000 |      43   |               297.53% |              1627.84% | 5.3e-08 |      20 |
- | String::Trim::NonRegex::trim |    300000 |       3.3 |              4983.90% |                35.11% | 1.5e-08 |      20 |
- | String::Trim::More::trim     |    400000 |       2.5 |              6768.62% |                 0.00% | 4.2e-09 |      20 |
+ | String::Trim::Regex::trim    |   18437.5 |   54.2374 |                 0.00% |              5517.15% | 1.2e-11 |      28 |
+ | String::Util::trim           |   22900   |   43.6    |                24.39% |              4415.65% | 1.2e-08 |      26 |
+ | String::Trim::More::trim     |  390540   |    2.5605 |              2018.21% |               165.18% | 9.5e-12 |      20 |
+ | Text::Minify::XS::minify     |  557270   |    1.7945 |              2922.48% |                85.85% | 1.1e-11 |      20 |
+ | String::Trim::NonRegex::trim | 1036000   |    0.9656 |              5517.15% |                 0.00% | 9.8e-12 |      20 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table3#
@@ -170,10 +183,11 @@ Benchmark with default options (C<< bencher -m StringFunctions::Trim >>):
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Trim::Regex::trim    |      5700 |     180   |                 0.00% |              6979.99% | 8.1e-07 |      22 |
- | String::Util::trim           |     20000 |      49   |               257.49% |              1880.48% | 1.1e-07 |      22 |
- | String::Trim::NonRegex::trim |     84000 |      12   |              1381.40% |               377.92% | 1.3e-08 |      20 |
- | String::Trim::More::trim     |    400000 |       2.5 |              6979.99% |                 0.00% | 3.3e-09 |      20 |
+ | String::Trim::Regex::trim    |   18428.2 |   54.2646 |                 0.00% |              2872.02% | 9.8e-12 |      29 |
+ | String::Util::trim           |   22900   |   43.6    |                24.40% |              2289.01% | 1.1e-08 |      31 |
+ | String::Trim::NonRegex::trim |  306750   |    3.26   |              1564.58% |                78.54% | 1.1e-11 |      21 |
+ | String::Trim::More::trim     |  388090   |    2.5767 |              2005.96% |                41.12% | 9.1e-12 |      20 |
+ | Text::Minify::XS::minify     |  547690   |    1.8259 |              2872.02% |                 0.00% | 1.2e-11 |      20 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table4#
@@ -181,10 +195,11 @@ Benchmark with default options (C<< bencher -m StringFunctions::Trim >>):
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Trim::Regex::trim    |      5900 |     170   |                 0.00% |              6383.02% | 2.1e-07 |      20 |
- | String::Trim::NonRegex::trim |      9000 |     100   |                46.95% |              4311.63% | 3.1e-06 |      20 |
- | String::Util::trim           |     23000 |      43   |               297.42% |              1531.29% | 5.3e-08 |      20 |
- | String::Trim::More::trim     |    380000 |       2.6 |              6383.02% |                 0.00% | 3.3e-09 |      20 |
+ | String::Trim::Regex::trim    |   18366.5 |   54.4469 |                 0.00% |              2418.31% | 1.1e-11 |      20 |
+ | String::Util::trim           |   22843.4 |   43.7763 |                24.38% |              1924.76% | 9.4e-12 |      29 |
+ | String::Trim::NonRegex::trim |   40200   |   24.9    |               118.68% |              1051.59% | 6.2e-09 |      23 |
+ | String::Trim::More::trim     |  368000   |    2.72   |              1905.05% |                25.60% | 8.3e-10 |      20 |
+ | Text::Minify::XS::minify     |  463000   |    2.16   |              2418.31% |                 0.00% | 6.8e-10 |      30 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table5#
@@ -192,10 +207,11 @@ Benchmark with default options (C<< bencher -m StringFunctions::Trim >>):
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Trim::NonRegex::trim |      1100 |     920   |                 0.00% |             24266.77% | 1.8e-06 |      20 |
- | String::Trim::Regex::trim    |      5800 |     170   |               436.16% |              4444.69% | 2.7e-07 |      20 |
- | String::Util::trim           |     23000 |      44   |              1981.75% |              1070.49% | 6.5e-08 |      21 |
- | String::Trim::More::trim     |    260000 |       3.8 |             24266.77% |                 0.00% | 6.7e-09 |      20 |
+ | String::Trim::NonRegex::trim |      4140 |  242      |                 0.00% |              6138.52% | 4.7e-08 |      26 |
+ | String::Trim::Regex::trim    |     18000 |   55      |               336.14% |              1330.41% |   1e-07 |      21 |
+ | String::Util::trim           |     22133 |   45.1814 |               435.05% |              1065.97% | 1.1e-11 |      20 |
+ | Text::Minify::XS::minify     |    207920 |    4.8095 |              4926.30% |                24.12% | 9.8e-12 |      22 |
+ | String::Trim::More::trim     |    258000 |    3.87   |              6138.52% |                 0.00% | 1.7e-09 |      20 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table6#
@@ -203,10 +219,11 @@ Benchmark with default options (C<< bencher -m StringFunctions::Trim >>):
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Trim::Regex::trim    |     53102 |    18.832 |                 0.00% |               660.17% | 4.5e-11 |      20 |
- | String::Util::trim           |     71000 |    14     |                34.37% |               465.73% | 2.7e-08 |      20 |
- | String::Trim::NonRegex::trim |    310000 |     3.2   |               483.90% |                30.19% | 1.3e-08 |      20 |
- | String::Trim::More::trim     |    400000 |     2.5   |               660.17% |                 0.00% | 6.8e-09 |      20 |
+ | String::Trim::Regex::trim    |    166350 |    6.0113 |                 0.00% |              1854.25% | 4.6e-11 |      20 |
+ | String::Util::trim           |    195810 |    5.107  |                17.71% |              1560.27% | 5.2e-12 |      24 |
+ | String::Trim::More::trim     |   1052000 |    0.9507 |               532.32% |               209.06% | 1.1e-11 |      20 |
+ | String::Trim::NonRegex::trim |   1100000 |    0.95   |               533.45% |               208.51% | 1.2e-09 |      20 |
+ | Text::Minify::XS::minify     |   3251000 |    0.3076 |              1854.25% |                 0.00% | 1.1e-11 |      20 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table7#
@@ -214,10 +231,11 @@ Benchmark with default options (C<< bencher -m StringFunctions::Trim >>):
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Trim::Regex::trim    |     53000 |      19   |                 0.00% |               647.47% | 3.3e-08 |      20 |
- | String::Util::trim           |     72000 |      14   |                36.82% |               446.30% | 3.3e-08 |      20 |
- | String::Trim::NonRegex::trim |     84000 |      12   |                60.14% |               366.77% | 1.3e-08 |      20 |
- | String::Trim::More::trim     |    390000 |       2.5 |               647.47% |                 0.00% | 1.1e-08 |      20 |
+ | String::Trim::Regex::trim    |    166340 |   6.0119  |                 0.00% |              1658.63% | 1.1e-11 |      20 |
+ | String::Util::trim           |    195831 |   5.10643 |                17.73% |              1393.76% |   0     |      20 |
+ | String::Trim::NonRegex::trim |    309660 |   3.2293  |                86.16% |               844.67% |   1e-11 |      21 |
+ | String::Trim::More::trim     |   1044000 |   0.9581  |               527.48% |               180.27% |   1e-11 |      20 |
+ | Text::Minify::XS::minify     |   2930000 |   0.342   |              1658.63% |                 0.00% | 9.8e-11 |      23 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table8#
@@ -225,36 +243,39 @@ Benchmark with default options (C<< bencher -m StringFunctions::Trim >>):
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Trim::NonRegex::trim |     10000 |        96 |                 0.00% |              7887.53% | 1.1e-07 |      20 |
- | String::Trim::Regex::trim    |     52000 |        19 |               396.11% |              1510.03% | 2.6e-08 |      21 |
- | String::Util::trim           |    200000 |         7 |              1366.84% |               444.54% | 8.5e-08 |      20 |
- | String::Trim::More::trim     |    800000 |         1 |              7887.53% |                 0.00% | 1.7e-08 |      24 |
+ | String::Trim::NonRegex::trim |     40200 |   24.9    |                 0.00% |              3898.58% | 6.2e-09 |      23 |
+ | String::Trim::Regex::trim    |    163780 |    6.1057 |               307.52% |               881.20% | 1.1e-11 |      20 |
+ | String::Util::trim           |    187000 |    5.34   |               365.92% |               758.21% | 4.9e-09 |      21 |
+ | String::Trim::More::trim     |    860000 |    1.2    |              2032.68% |                87.49% | 1.2e-09 |      20 |
+ | Text::Minify::XS::minify     |   1607000 |    0.6223 |              3898.58% |                 0.00% |   1e-11 |      20 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table9#
  {dataset=>"len10ws1"}
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | participant                  | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ | participant                  | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | String::Trim::Regex::trim    |    280000 |       3.6 |                 0.00% |                76.85% | 6.7e-09 |      20 |
- | String::Util::trim           |    310000 |       3.3 |                 9.01% |                62.24% | 6.7e-09 |      20 |
- | String::Trim::NonRegex::trim |    310000 |       3.3 |                 9.07% |                62.15% | 6.7e-09 |      20 |
- | String::Trim::More::trim     |    500000 |       2   |                76.85% |                 0.00% | 6.7e-09 |      20 |
+ | String::Util::trim           |    849000 |    1180   |                 0.00% |               686.70% | 4.2e-10 |      20 |
+ | String::Trim::Regex::trim    |    866730 |    1153.8 |                 2.10% |               670.53% | 1.1e-11 |      20 |
+ | String::Trim::NonRegex::trim |   1050000 |     949   |                24.19% |               533.47% | 3.6e-10 |      27 |
+ | String::Trim::More::trim     |   1380000 |     727   |                62.09% |               385.35% | 2.1e-10 |      20 |
+ | Text::Minify::XS::minify     |   6678000 |     149.7 |               686.70% |                 0.00% |   1e-11 |      20 |
  +------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m StringFunctions::Trim --module-startup >>):
 
  #table10#
- +------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | participant            | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
- +------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | String::Util           |        23 |                13 |                 0.00% |               104.86% | 9.4e-05   |      20 |
- | String::Trim::Regex    |        21 |                11 |                 8.32% |                89.12% |   0.00021 |      20 |
- | String::Trim::More     |        20 |                10 |                36.41% |                50.18% |   0.00021 |      20 |
- | String::Trim::NonRegex |        16 |                 6 |                46.69% |                39.66% |   0.00014 |      20 |
- | perl -e1 (baseline)    |        10 |                 0 |               104.86% |                 0.00% |   0.0002  |      20 |
- +------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
+ +------------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ | participant            | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +------------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ | String::Util           |     14    |              7.7  |                 0.00% |               126.68% |   3e-05 |      20 |
+ | String::Trim::Regex    |     12    |              5.7  |                18.48% |                91.32% | 1.8e-05 |      20 |
+ | Text::Minify::XS       |      9.14 |              2.84 |                56.53% |                44.82% | 8.5e-06 |      20 |
+ | String::Trim::More     |      9    |              2.7  |                58.35% |                43.16% | 1.5e-05 |      20 |
+ | String::Trim::NonRegex |      9    |              2.7  |                59.71% |                41.94% | 1.5e-05 |      20 |
+ | perl -e1 (baseline)    |      6.3  |              0    |               126.68% |                 0.00% | 2.7e-05 |      20 |
+ +------------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
