@@ -1,7 +1,7 @@
 package Bencher::Scenario::StringModules::Startup;
 
-our $DATE = '2021-06-16'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-06-23'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -32,7 +32,7 @@ Bencher::Scenario::StringModules::Startup - Benchmark startup of string modules
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::StringModules::Startup (from Perl distribution Bencher-Scenarios-StringFunctions), released on 2021-06-16.
+This document describes version 0.003 of Bencher::Scenario::StringModules::Startup (from Perl distribution Bencher-Scenarios-StringFunctions), released on 2021-06-23.
 
 =head1 SYNOPSIS
 
@@ -99,11 +99,11 @@ Benchmark with default options (C<< bencher -m StringModules::Startup >>):
  +----------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
  | participant          | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +----------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
- | String::Util         |        20 |                10 |                 0.00% |               101.84% | 0.00048 |      20 |
- | String::CommonSuffix |        10 |                 0 |                45.83% |                38.41% | 0.00041 |      20 |
- | String::Trim::More   |        10 |                 0 |                59.03% |                26.92% | 0.00032 |      20 |
- | String::CommonPrefix |        10 |                 0 |                67.34% |                20.61% | 0.00033 |      20 |
- | perl -e1 (baseline)  |        10 |                 0 |               101.84% |                 0.00% | 0.00025 |      21 |
+ | String::Util         |      14   |               7.4 |                 0.00% |               118.92% | 3.4e-05 |      20 |
+ | String::CommonPrefix |       9.3 |               2.7 |                54.98% |                41.25% | 4.1e-05 |      22 |
+ | String::Trim::More   |       9.2 |               2.6 |                55.86% |                40.46% | 1.1e-05 |      20 |
+ | String::CommonSuffix |       9.1 |               2.5 |                57.88% |                38.66% | 5.8e-05 |      20 |
+ | perl -e1 (baseline)  |       6.6 |               0   |               118.92% |                 0.00% | 3.5e-05 |      20 |
  +----------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
 
 
